'use strict';

const stylesheetInjector = require('stylesheet-injector');

const optionsNormilizer = require('./lib/normalize-options');
const createElement = require('./lib/create-element');
const styles = require('./lib/style.json');
const guid = require('./lib/guid.json');

module.exports = Inlineinput;

/**
 * @constructor
 * @param {Object} options - Configuration object (See documentation)
 */
function Inlineinput (options) {
  if (!(this instanceof Inlineinput)) return new Inlineinput(options);
  const config = optionsNormilizer(options);
  this.config = config;
  this.element = createElement(config);
  stylesheetInjector(`ui-inline-input-${guid}`, styles);
}

/**
 * @member Give focus to the input element
 */
Inlineinput.prototype.focus = function () {
  this.element.inputField.focus();
};

/**
 * @member Set the element's value
 * @param {String} val - Value to set
 */
Inlineinput.prototype.setValue = function (val) {
  this.element.inputField.setValue(val);
  this.config.onValueChanged.forEach(f => {
    f(this.element.inputField.getValue());
  });
};

/**
 * @member Get the element's current value
 * @return {String}
 */
Inlineinput.prototype.getValue = function () {
  return this.element.inputField.getValue();
};

/**
 * @member Disable the input field
 */
Inlineinput.prototype.disable = function () {
  this.element.inputField.disable();
  this.element.classList.add(`ui-inline-input-${guid}--disabled`);
};


/**
 * @member Enable the input field
 */
Inlineinput.prototype.enable = function () {
  this.element.inputField.enable();
  this.element.classList.remove(`ui-inline-input-${guid}--disabled`);
};
